@@ -8,6 +8,7 @@ import traceback
 from collections.abc import Iterator, Mapping
 from contextlib import contextmanager
 from numbers import Number
+from typing import Callable, TypeVar, overload
 
 import numpy as np
 import pandas as pd
@@ -140,6 +141,18 @@ infer the metadata. This may lead to unexpected results, so providing
 ``dask.dataframe.utils.make_meta``.
 """
 
+T = TypeVar("T", bound=Callable)
+
+
+@overload
+def insert_meta_param_description(func: T) -> T:
+    ...
+
+
+@overload
+def insert_meta_param_description(pad: int) -> Callable[[T], T]:
+    ...
+
 
 def insert_meta_param_description(*args, **kwargs):
     """Replace `$META` in docstring with param description.
@@ -285,9 +298,10 @@ def clear_known_categories(x, cols=None, index=True):
 
 def _empty_series(name, dtype, index=None):
     if isinstance(dtype, str) and dtype == "category":
-        return pd.Series(
-            pd.Categorical([UNKNOWN_CATEGORIES]), name=name, index=index
-        ).iloc[:0]
+        s = pd.Series(pd.Categorical([UNKNOWN_CATEGORIES]), name=name).iloc[:0]
+        if index is not None:
+            s.index = make_meta(index)
+        return s
     return pd.Series([], dtype=dtype, name=name, index=index)
 
 
